@@ -2,16 +2,17 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .party import *
-from .payment_term import *
-from .invoice import *
+
+from . import account, account_invoice, party
 
 
 def register():
     Pool.register(
-        Party,
-        Address,
-        PaymentTerm,
-        PaymentTermLine,
-        Invoice,
+        party.Party,
+        party.Address,
+        party.Identifier,
+        account.Invoice,
+        account_invoice.PaymentTerm,
+        account_invoice.PaymentTermLine,
+        account_invoice.PaymentTermLineRelativeDelta,
         module='account_invoice_history', type_='model')
