@@ -5,7 +5,7 @@ from sql.conditionals import Greatest
 from sql.functions import CurrentTimestamp
 
 from trytond.model import ModelView, Workflow, fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.tools import grouped_slice, reduce_ids
 from trytond.transaction import Transaction
 
@@ -37,24 +37,21 @@ class Invoice(metaclass=PoolMeta):
         super(Invoice, cls).__setup__()
         cls._check_modify_exclude.add('numbered_at')
         cls.party.datetime_field = 'history_datetime'
-        if 'history_datetime' not in cls.party.depends:
-            cls.party.depends.append('history_datetime')
+        cls.party_tax_identifier.datetime_field = 'history_datetime'
         cls.invoice_address.datetime_field = 'history_datetime'
-        if 'history_datetime' not in cls.invoice_address.depends:
-            cls.invoice_address.depends.append('history_datetime')
         cls.payment_term.datetime_field = 'history_datetime'
-        if 'history_datetime' not in cls.payment_term.depends:
-            cls.payment_term.depends.append('history_datetime')
 
     @classmethod
     def get_history_datetime(cls, invoices, name):
         pool = Pool()
         Party = pool.get('party.party')
         Address = pool.get('party.address')
+        Identifier = pool.get('party.identifier')
         PaymentTerm = pool.get('account.invoice.payment_term')
         table = cls.__table__()
         party = Party.__table__()
         address = Address.__table__()
+        identifier = Identifier.__table__()
         payment_term = PaymentTerm.__table__()
         cursor = Transaction().connection.cursor()
 
@@ -64,11 +61,14 @@ class Invoice(metaclass=PoolMeta):
             cursor.execute(*table
                 .join(party, condition=table.party == party.id)
                 .join(address, condition=table.invoice_address == address.id)
+                .join(identifier, 'LEFT',
+                    condition=table.party_tax_identifier == identifier.id)
                 .join(payment_term, 'LEFT',
                     condition=table.payment_term == payment_term.id)
                 .select(table.id,
                     Greatest(table.numbered_at, party.create_date,
-                        address.create_date, payment_term.create_date),
+                        address.create_date, identifier.create_date,
+                        payment_term.create_date),
                     where=reduce_ids(table.id, ids)
                     & (table.numbered_at != Null)
                     & (table.state.in_(cls._history_states()))))
