@@ -2,8 +2,6 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import PoolMeta
 
-__all__ = ['Party', 'Address']
-
 
 class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
@@ -13,3 +11,8 @@ class Party(metaclass=PoolMeta):
 class Address(metaclass=PoolMeta):
     __name__ = 'party.address'
     _history = True
+
+
+class Identifier(metaclass=PoolMeta):
+    __name__ = 'party.identifier'
+    _history = True
